/*
 * This file is part of Quiz-App.
 *
 * Quiz-App is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.

 * Quiz-App is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.

 * You should have received a copy of the GNU General Public License
 * along with Quiz-App. If not, see <https://www.gnu.org/licenses/>.
 */
package ch.jaermann.quiz.controller;

import java.util.ArrayList;
import java.util.List;

import ch.jaermann.quiz.model.Answer;
import ch.jaermann.quiz.model.Question;
import ch.jaermann.quiz.model.Quiz;
import lombok.Data;
import lombok.extern.log4j.Log4j2;

/**
 * Controller for Quiz eigenes Json Format.
 */
@Data
@Log4j2
public class QuizController {
	
	private Quiz quiz;
	
	public QuizController(Quiz quiz) {
		this.quiz = quiz;
	}
	
	public List<Integer> getAllIDs() {
		
		List<Integer> ids = new ArrayList<>();
		
		for (Question question : quiz.getQuestions()) {
			ids.add(question.getId());
		}
		return ids;
	}

	public Question getQuestionsID(Integer id) {
		
		for (Question question : quiz.getQuestions()) {
			if (question.getId() == id) {
				return question;
			}
		}

		String toLog="Question with id "+id+" not found";
		System.out.println(toLog);
		log.error(toLog);
		throw new IllegalArgumentException(toLog);
	}
	
	public int calculateTotalPoints(Quiz quiz) {
		int points = 0;
		for (Question question : quiz.getQuestions()) {

			points += calculateTotalPoints(question);
		}
		return points;
	}
	
	public int calculateTotalPoints() {
		 return calculateTotalPoints(quiz);
	}
	
	/**
	 * Errechnet die maximale Punkte Zahl der gegebenen Frage.
	 * @param question
	 * @return Die maximale Punktzahl der Frage
	 */
	public static int calculateTotalPoints(Question question) {
		int points = 0;
		for (Answer answer : question.getAnswers()) {
			if (answer.getAnswerPoints() > 0) {
				points += answer.getAnswerPoints();
			}
		}
		return points;
	}

	public Quiz getQuestionsWithId(List<Integer> list) {
		List<Question> questions = new ArrayList<>();
		for (Integer id : list) {
			questions.add(getQuestionsID(id));
		}
		Quiz quiz = new Quiz();
		quiz.setQuestions(questions);
		return quiz;
	}
}
