/*
 * This file is part of Quiz-App.
 *
 * Quiz-App is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.

 * Quiz-App is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.

 * You should have received a copy of the GNU General Public License
 * along with Quiz-App. If not, see <https://www.gnu.org/licenses/>.
 */
package ch.jaermann.quiz.creater;

import java.io.File;
import java.io.IOException;

import ch.jaermann.quiz.model.Quiz;

/**
 * Oberklasse für alle Klassen, die ein Dokument erstellen.<br>
 * Konkret die Klassen, welche ein Quiz in einem konkreten Format erstellen (TXT, ADOC, SM, ..).
 */
public abstract class DocumentCreater {
	
	/**
	 * erstellt das eigentliche Output Dokument.<br>
	 * 
	 * @param quiz       Den Fragepool
	 * @param template   Das Dokument welches als Ausgangsdokument dient. <br>
	 *                   Die Datei welche bearbeitet wird und danach als output
	 *                   ausgegeben wird.
	 * @param outputFile Die destination an welche der Output geschrieben werden
	 *                   soll.
	 * @return Ob das erzeugen erfolgreich war oder nicht.
	 * @throws IOException
	 */
	public abstract boolean create(Quiz quiz, File template, File outputFile) throws IOException;
	
}
