/*
 * This file is part of Quiz-App.
 *
 * Quiz-App is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.

 * Quiz-App is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.

 * You should have received a copy of the GNU General Public License
 * along with Quiz-App. If not, see <https://www.gnu.org/licenses/>.
 */
package ch.jaermann.quiz.creater;

import ch.jaermann.quiz.creater.adoc.DocumentCreaterAdoc;
import ch.jaermann.quiz.creater.libreoffice.DocumentCreaterLibreoffice;
import ch.jaermann.quiz.creater.smartlearn.DocumentCreaterSmartLearn;
import ch.jaermann.quiz.creater.txt.DocumentCreaterTxt;
import lombok.extern.log4j.Log4j2;

@Log4j2
public class DocumentCreaterFactory {
	
	public static DocumentCreater create(String type) throws IllegalArgumentException {
		
		switch (type) {
		case "txt":
			log.info("using outputType txt");
			return new DocumentCreaterTxt();
		case "adoc":
			log.info("using outputType adoc");
			return new DocumentCreaterAdoc();
		case "sm":
			log.info("using outputType smartlearn");
			return new DocumentCreaterSmartLearn();
		case "libre":
			log.info("using outputType libreoffice");
			return new DocumentCreaterLibreoffice();
		default:
			log.error("Unknown outputType: " + type);
			throw new IllegalArgumentException("Unknown outputType: " + type);
		}
	}
}
