/*
 * This file is part of Quiz-App.
 *
 * Quiz-App is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.

 * Quiz-App is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.

 * You should have received a copy of the GNU General Public License
 * along with Quiz-App. If not, see <https://www.gnu.org/licenses/>.
 */
package ch.jaermann.quiz.creater.adoc.controller;

import ch.jaermann.quiz.Helper;
import ch.jaermann.quiz.model.Answer;
import ch.jaermann.quiz.model.MultipleChoiceQuestion;

public class MultipleChoiceQuestionController extends QuestionController {
	
	private MultipleChoiceQuestion question;
	
	/** question Template */
	private static String questionTemplate = ""
			+ "${titel}\n"
			+ "\n" 
			+ "[auftrag]\n" 
			+ "====\n" 
			+ "${Question} \n" 
			+ "\\vspace{0.5cm}\n"
			+ "${a}\n"
			+ "====\n"
			+ "";

	public MultipleChoiceQuestionController(ch.jaermann.quiz.model.MultipleChoiceQuestion question) {
		this.question = question;
	}

	@Override
	public StringBuilder toAdoc() {

		StringBuilder q = new StringBuilder(questionTemplate);
		
		
		if (question.getTitel() != null && ! question.getTitel().isBlank()) {
			// ersetzte ${titel} mit Titel
			Helper.replaceFirst(q, "${titel}", question.getTitel());				
		}
		Helper.replaceFirst(q, "${titel}", "");

		// ersetzte ${Question} mit Frage
		Helper.replaceFirst(q, "${Question}", question.getQuestionText());

		// ersetzte {answer} mit Antworten
		int j=0;
		for (Answer answer : question.getAnswers()) {
			
			String eindeutigeID = "id"+question.getId()+"-" + j++;
			String a = ""
					+ "\n" 
					+ "\\Checkbox{" + eindeutigeID + "}{0mm}{\n"  // Checkbox mit eindeutiger id
					+ "${a}\n" 
					+ "}\n"
					+ "${a}";
			
			a=Helper.replaceFirst(a, "${a}", answer.getAnswerText());
			
			q=Helper.replaceFirst(q, "${a}", a);
			q.append("");
		}
		q=Helper.replaceFirst(q, "${a}", "");
		return q;
	}

}
