/*
 * This file is part of Quiz-App.
 *
 * Quiz-App is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.

 * Quiz-App is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.

 * You should have received a copy of the GNU General Public License
 * along with Quiz-App. If not, see <https://www.gnu.org/licenses/>.
 */
package ch.jaermann.quiz.creater.libreoffice;

import java.io.IOException;

import org.odftoolkit.odfdom.doc.OdfDocument;
import org.odftoolkit.odfdom.dom.element.text.TextPElement;
import org.odftoolkit.odfdom.incubator.search.TextSelection;
import org.xml.sax.SAXException;

import ch.jaermann.quiz.model.Question;

public abstract class QuestionController {
	
	protected Question question;
	protected OdfDocument doc;

	public QuestionController(Question question, OdfDocument doc) {
		this.question = question;
		this.doc = doc;
	}
	
	public abstract TextPElement create(TextSelection selection) throws SAXException, IOException;
	
	public TextPElement createTitel(TextSelection selection) throws SAXException, IOException {
		
		// Erstelle ein neues Paragraph-Element für den Text der Frage
		TextPElement element = new TextPElement(doc.getContentDom());
		// Füge den neuen Paragraphen in das Dokument ein, direkt vor dem aktuellen selection-Element
		selection.getContainerElement().getParentNode().insertBefore(element, selection.getElement());
		
		element.setTextContent(question.getTitel());
		return element;
    }
	
	public TextPElement createText(TextSelection selection) throws SAXException, IOException {
		
		// Erstelle ein neues Paragraph-Element für den Text der Frage
		TextPElement element = new TextPElement(doc.getContentDom());
		// Füge den neuen Paragraphen in das Dokument ein, direkt vor dem aktuellen selection-Element
		selection.getContainerElement().getParentNode().insertBefore(element, selection.getElement());
		
		element.setTextContent(question.getQuestionText());
		return element;
	}

}
