/*
 * This file is part of Quiz-App.
 *
 * Quiz-App is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.

 * Quiz-App is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.

 * You should have received a copy of the GNU General Public License
 * along with Quiz-App. If not, see <https://www.gnu.org/licenses/>.
 */
package ch.jaermann.quiz.creater.libreoffice;

import java.io.IOException;
import java.util.Iterator;

import org.odftoolkit.odfdom.doc.OdfDocument;
import org.odftoolkit.odfdom.dom.element.text.TextPElement;
import org.odftoolkit.odfdom.incubator.search.TextSelection;
import org.xml.sax.SAXException;

import ch.jaermann.quiz.model.Answer;
import ch.jaermann.quiz.model.SingleChoiceQuestion;

public class SingleChoiceQuestionController extends QuestionController {

	public SingleChoiceQuestionController(SingleChoiceQuestion question, OdfDocument doc) {
		super(question, doc);
	}

	@Override
	public TextPElement create(TextSelection selection) throws SAXException, IOException {
		
		// Erstelle ein neues Paragraph-Element für den Text der Frage
		TextPElement questionTextParagraph = new TextPElement(doc.getContentDom());
		// Füge den neuen Paragraphen in das Dokument ein, direkt vor dem aktuellen selection-Element
		selection.getContainerElement().getParentNode().insertBefore(questionTextParagraph, selection.getElement());
		
		questionTextParagraph.setTextContent(question.getQuestionText());
		
		// Antworten Anfügen
		for (Iterator<Answer> iterator = question.getAnswers().iterator(); iterator.hasNext();) {
			Answer answer = iterator.next();

			// Erstelle ein neues Paragraph-Element für jede Antwort möglichkeit der Frage
			TextPElement questionAnswerParagraph = new TextPElement(doc.getContentDom());
			questionAnswerParagraph.setTextContent('\u25ef' + " " + answer.getAnswerText());
			// Füge den neuen Paragraphen in das Dokument ein, direkt nach dem aktuellen selection-Element
			questionTextParagraph.getParentNode().insertBefore(questionAnswerParagraph, selection.getElement());
			
			// Funktioniert nur sind die Paragraphen in der falschen reihenfolge
			// questionTextParagraph.getParentNode().insertBefore(questionAnswerParagraph, questionTextParagraph);
		}

		// Noch ein Paragraph anhängen für die Distanz zwischen den Fragen
		TextPElement p = new TextPElement(doc.getContentDom());
		// Füge den neuen Paragraphen in das Dokument ein, direkt vor dem aktuellen selection-Element
		questionTextParagraph.getParentNode().insertBefore(p, selection.getElement());

		return questionTextParagraph;
	}

}
