/*
 * This file is part of Quiz-App.
 *
 * Quiz-App is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.

 * Quiz-App is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.

 * You should have received a copy of the GNU General Public License
 * along with Quiz-App. If not, see <https://www.gnu.org/licenses/>.
 */
package ch.jaermann.quiz.creater.smartlearn.controller;

import java.util.ArrayList;
import java.util.Iterator;

import ch.jaermann.quiz.controller.QuizController;
import ch.jaermann.quiz.creater.smartlearn.DocumentCreaterSmartLearn;
import ch.jaermann.quiz.model.Answer;
import ch.jaermann.quiz.model.MultipleChoiceQuestion;
import ch.jaermann.quiz.model.Question;
import ch.jaermann.quiz.model.Quiz;
import ch.jaermann.quiz.smartlearn.model.ChoiceMultipleChoiceBlock;
import ch.jaermann.quiz.smartlearn.model.MultipleChoiceBlock;
import ch.jaermann.quiz.smartlearn.model.RichTextBlock;
import ch.jaermann.quiz.smartlearn.model.SolutionMultipleChoiceBlock;
import ch.jaermann.quiz.smartlearn.model.TaskBlock;

/**
 * Builder for multiple choice questions. <br>
 * erstellt aus einem MultipleChoiceQuestion eine in SM importierbare MultipleChoiceFrage
 *
 */
public class MultipeChoiceQuestionBuilder extends QuestionBuilder{
	
	public MultipeChoiceQuestionBuilder(DocumentCreaterSmartLearn doc, Quiz quiz) {
		super(doc, quiz);
	}
	
	@Override
	public TaskBlock create(Question question) {
		
		question = (MultipleChoiceQuestion) question;
		
		TaskBlock smTaskBlock = new TaskBlock(); // Gefäss für die Fragen
		String title = question.getTitel();      // SM hat etwas gegen leere Titel....
		if(title==null || title.isEmpty()) {
			title=question.getQuestionText();
		}		
		smTaskBlock.setTitle(title);                 // smTaskBlock.setTitle("Aufgabe 1");
		
		int p=QuizController.calculateTotalPoints(question);
		smTaskBlock.setPoints("" + p);               // Warum hier Punkte und bei MultipleChoiceBlock auch?
		
		smTaskBlock.setImportId(194554);             // Woher die zahl??
		smTaskBlock.setImportId(doc.getSmImportId().incrementAndGet()); // Woher die zahl?? -> ganz einfach aufsteigend vergeben....

		RichTextBlock smRichTextBlock = new RichTextBlock();
		smTaskBlock.addBlock(smRichTextBlock);

		smRichTextBlock.setContent(question.getQuestionText());             // smRichTextBlock.setContent("Content der Frage 1");
		smRichTextBlock.setImportId(194549);                                // Woher die zahl??
		smRichTextBlock.setImportId(doc.getSmImportId().incrementAndGet()); // Woher die zahl?? -> ganz einfach aufsteigend vergeben....
		
		MultipleChoiceBlock smMultipleChoiceBlock = new MultipleChoiceBlock(); // Enthällt in der Regel die Antworten, hier wird aber gleich die Ableitung verwendet.
		smTaskBlock.addBlock(smMultipleChoiceBlock);

		p=QuizController.calculateTotalPoints(question);
		smMultipleChoiceBlock.setPoints(""+p);        // Warum hier Punkte und bei TaskBlock auch?
		
		smMultipleChoiceBlock.setImportId(194548);
		smMultipleChoiceBlock.setImportId(doc.getSmImportId().incrementAndGet());
		
		// smMultipleChoiceBlock.setPosition(xx); // wird im Konstruktor von MultipleChoiceBlock erledigt.
		
		// Antworten möglichkeiten setzen
		ArrayList<String> answersChoice = new ArrayList<>(); // Liste der korrekten Antworten
		
		for (Iterator<Answer> iterator = question.getAnswers().iterator(); iterator.hasNext();) {
			Answer a = iterator.next();

			ChoiceMultipleChoiceBlock smChoiceMultipleChoiceBlock = new ChoiceMultipleChoiceBlock();
			smMultipleChoiceBlock.addChoice(smChoiceMultipleChoiceBlock);
			String id = DocumentCreaterSmartLearn.generateRandomCode();
			smChoiceMultipleChoiceBlock.setId("r486l287rmh");
			smChoiceMultipleChoiceBlock.setId(id);
			// Falls diese question eine Punkteanzahl höher 0 hat muss die id für die
			// Antwort gesetzt werden
			if (a.getAnswerPoints() > 0)
				answersChoice.add(id);

			smChoiceMultipleChoiceBlock.setValue("<p>Antwort 1<\\/p>");
			smChoiceMultipleChoiceBlock.setValue(a.getAnswerText());
		}
	
		// Lösung setzen
		SolutionMultipleChoiceBlock smSolutionMultipleChoiceBlock = new SolutionMultipleChoiceBlock();
		smMultipleChoiceBlock.setSolution(smSolutionMultipleChoiceBlock);
		smSolutionMultipleChoiceBlock.setImportId(556127);
		smSolutionMultipleChoiceBlock.setImportId(doc.getSmImportId().incrementAndGet());
		for (String s : answersChoice) {
			smSolutionMultipleChoiceBlock.addChoice(s);
		}
		
		return smTaskBlock;
	}
	
}
