/*
 * This file is part of Quiz-App.
 *
 * Quiz-App is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.

 * Quiz-App is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.

 * You should have received a copy of the GNU General Public License
 * along with Quiz-App. If not, see <https://www.gnu.org/licenses/>.
 */
package ch.jaermann.quiz.creater.smartlearn.controller;

import ch.jaermann.quiz.creater.smartlearn.DocumentCreaterSmartLearn;
import ch.jaermann.quiz.model.MultipleChoiceQuestion;
import ch.jaermann.quiz.model.Question;
import ch.jaermann.quiz.model.Quiz;
import ch.jaermann.quiz.model.SingleChoiceQuestion;

public class QuestionBuilderFactory {

	private DocumentCreaterSmartLearn doc;
	private Quiz quiz;

	public QuestionBuilderFactory(DocumentCreaterSmartLearn doc, Quiz quiz) {
		this.doc = doc;
		this.quiz = quiz;
	}

	public QuestionBuilder create(Question q) {
		
		if (q instanceof MultipleChoiceQuestion) {
			return new MultipeChoiceQuestionBuilder(doc, quiz);
		}
		if (q instanceof SingleChoiceQuestion) {
			return new SingleChoiceQuestionBuilder(doc, quiz);
		}
		
		throw new UnsupportedQuestionTypeException("Unsupported question type: " + q.getClass().getName());
	}

}
