/*
 * This file is part of Quiz-App.
 *
 * Quiz-App is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.

 * Quiz-App is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.

 * You should have received a copy of the GNU General Public License
 * along with Quiz-App. If not, see <https://www.gnu.org/licenses/>.
 */
package ch.jaermann.quiz.creater.smartlearn.controller;

import java.util.ArrayList;

import ch.jaermann.quiz.controller.QuizController;
import ch.jaermann.quiz.creater.smartlearn.DocumentCreaterSmartLearn;
import ch.jaermann.quiz.model.Answer;
import ch.jaermann.quiz.model.Question;
import ch.jaermann.quiz.model.Quiz;
import ch.jaermann.quiz.model.SingleChoiceQuestion;
import ch.jaermann.quiz.smartlearn.model.ChoiceSingleChoiceBlock;
import ch.jaermann.quiz.smartlearn.model.RichTextBlock;
import ch.jaermann.quiz.smartlearn.model.SingleChoiceBlock;
import ch.jaermann.quiz.smartlearn.model.SolutionSingleChoiceBlock;
import ch.jaermann.quiz.smartlearn.model.TaskBlock;

/**
 * Builder for single choice questions. <br>
 * erstellt aus einem SingleChoiceQuestion eine in SM importierbare SingleChoiceFrage
 *
 */
public class SingleChoiceQuestionBuilder extends QuestionBuilder{
	
	public SingleChoiceQuestionBuilder(DocumentCreaterSmartLearn doc, Quiz quiz) {
		super(doc, quiz);
	}
	
	@Override
	public TaskBlock create(Question question) {
		
		QuizController quizController = new QuizController(quiz);
		question = (SingleChoiceQuestion) question;
		
		TaskBlock smTaskBlock = new TaskBlock(); // Gefäss für die Fragen
		String title = question.getTitel(); // SM hat etwas gegen leere Titel....
		if(title==null || title.isEmpty()) {
			title=question.getQuestionText();
		}		
		smTaskBlock.setTitle(title);
		int p=QuizController.calculateTotalPoints(question);
		smTaskBlock.setPoints("" + p);                                  // Warum hier Punkte und bei MultipleChoiceBlock auch?
		smTaskBlock.setImportId(194554);                                // Woher die zahl??
		smTaskBlock.setImportId(doc.getSmImportId().incrementAndGet()); // Woher die zahl??

		RichTextBlock smRichTextBlock = new RichTextBlock();
		smTaskBlock.addBlock(smRichTextBlock);
		smRichTextBlock.setContent(question.getQuestionText());
		smRichTextBlock.setImportId(194549);                                // Woher die zahl??
		smRichTextBlock.setImportId(doc.getSmImportId().incrementAndGet()); // Woher die zahl??
		
		SingleChoiceBlock smSingleChoiceBlock = new SingleChoiceBlock(); // Antwort möglichkeiten
		smTaskBlock.addBlock(smSingleChoiceBlock);
		smSingleChoiceBlock.setPoints(""+p);        // Warum hier Punkte und bei TaskBlock auch?
		smSingleChoiceBlock.setImportId(194548);
		smSingleChoiceBlock.setImportId(doc.getSmImportId().incrementAndGet());

		// smSingleChoiceBlock.setPosition(1);          // immer 1? keine ahnung ganz sicher nie null! -> erledigt im Konstruktor
		
		// Antworten möglichkeiten setzen
		ArrayList<String> answersChoice = new ArrayList<>(); // Liste der korrekten Antworten
		
		for (int i = 0; i < question.getAnswers().size(); i++) {
			Answer a = question.getAnswers().get(i);
			
			ChoiceSingleChoiceBlock smChoiceSingleChoiceBlock1 = new ChoiceSingleChoiceBlock();
			smSingleChoiceBlock.addChoice(smChoiceSingleChoiceBlock1);
			String id = DocumentCreaterSmartLearn.generateRandomCode();
			smChoiceSingleChoiceBlock1.setId("r486l287rmh");
			smChoiceSingleChoiceBlock1.setId(id);
			// Falls diese question eine Punkteanzahl höher 0 hat muss die id für die
			// Antwort gesetzt werden
			if (a.getAnswerPoints() > 0)
				answersChoice.add(id);

			smChoiceSingleChoiceBlock1.setValue("<p>Antwort 1<\\/p>");
			smChoiceSingleChoiceBlock1.setValue(a.getAnswerText());
		}
	
		// Lösung setzen
		SolutionSingleChoiceBlock smSolutionSingleChoiceBlock = new SolutionSingleChoiceBlock();
		smSingleChoiceBlock.setSolution(smSolutionSingleChoiceBlock);
		smSolutionSingleChoiceBlock.setImportId(556127);
		smSolutionSingleChoiceBlock.setImportId(doc.getSmImportId().incrementAndGet());
		if(answersChoice.size()>0)
            smSolutionSingleChoiceBlock.setChoice(answersChoice.get(0));
		
		return smTaskBlock;
	}

}
