/*
 * This file is part of Quiz-App.
 *
 * Quiz-App is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.

 * Quiz-App is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.

 * You should have received a copy of the GNU General Public License
 * along with Quiz-App. If not, see <https://www.gnu.org/licenses/>.
 */
package ch.jaermann.quiz.model;

import java.util.List;

import com.fasterxml.jackson.annotation.JsonSubTypes;
import com.fasterxml.jackson.annotation.JsonTypeInfo;

import lombok.Data;

/**
 * The Question class represents a generic question in the quiz application.<br>
 * It serves as a base class for different types of questions such as 
 * MultipleChoiceQuestion, SingleChoiceQuestion, and OpenTextQuestion.<br>
 * 
 * This class uses Jackson annotations to handle polymorphic JSON serialization
 * and deserialization.<br>
 * 
 * Attributes:<br>
 * - id: The unique identifier of the question.<br>
 * - titel: The title of the question.<br>
 * - questionText: The text of the question.<br>
 * - answers: A list of possible answers to the question.<br>
 */
@JsonTypeInfo(
		use = JsonTypeInfo.Id.NAME,
		include = JsonTypeInfo.As.PROPERTY,
		property = "type"
		)
@JsonSubTypes({ 
	@JsonSubTypes.Type(value = MultipleChoiceQuestion.class, name = "MultipleChoice"),
	@JsonSubTypes.Type(value = SingleChoiceQuestion.class, name = "SingleChoice"),
	@JsonSubTypes.Type(value = OpenTextQuestion.class, name = "OpenTextChoice"),
})
@Data 
public abstract class Question {
	
    int id;
    String titel;
    String questionText;
    String solutionText; // Optionales Feld für den Text einer Musterlösung
    List<Answer> answers;
}