/*
 * This file is part of Quiz-App.
 *
 * Quiz-App is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.

 * Quiz-App is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.

 * You should have received a copy of the GNU General Public License
 * along with Quiz-App. If not, see <https://www.gnu.org/licenses/>.
 */
package ch.jaermann.quiz.smartlearn.model;

import java.util.concurrent.atomic.AtomicInteger;

import com.fasterxml.jackson.annotation.JsonSubTypes;
import com.fasterxml.jackson.annotation.JsonTypeInfo;

import lombok.Data;

@JsonTypeInfo(
		use = JsonTypeInfo.Id.NAME,
		include = JsonTypeInfo.As.PROPERTY,
		property = "type"
		)
@JsonSubTypes({
	@JsonSubTypes.Type(value = QuestionBlock.class),
	@JsonSubTypes.Type(value = RichTextBlock.class, name = "rich_text_block"),
	@JsonSubTypes.Type(value = TaskBlock.class, name = "task_block"),
})
@Data
public class Block {
	
	/**
	 * Work around: <br>
	 * Die position darf für SM nicht 0 sein. <br>
	 * Welcher Wert gesetzt werden kann und für was dieser gut sein soll wird durch
	 * das SM Team nicht bekannt gegeben. <br>
	 * Das hier ist der Versuch eine eindeutige Nummer zu generieren.
	 */
	private static AtomicInteger positionID = new AtomicInteger(1);
	
//	public enum Type {
//		multiple_choice_block, 			// MultipleChoiceQuestion
//		single_choice_block,			// SingleChoiceQuestion
//		right_wrong_assertion_block,	// Zwei Aussagen
//		matrix_choice_block,			// Matrix-Choice
//		right_wrong_dont_know_block,	// (Wahr/Falsch) Wahr Falsch aussagen 
//		
//		text_input_block,				// Textfeld als Antwort
//		code_area_block,				// Textfeld als Antwort (Code)
//		sequence_block,					// Reihenfolge von Elementen
//		
//		task_block,						// ???
//		
//		rich_text_block,				// Textblock, weder Frage noch Antwort einfach nur Text
//		code_block,						// Codeblock, weder Frage noch Antwort einfach nur Code
//		sequence_answer,                // Wird innerhalb von Solution benutzt
//	}
	
	public Block(){
		this.setPosition(Block.positionID.incrementAndGet());
	}
	
	/**
	 * Muss immer gesetzt werden, ansonsten kommt SM durcheinander <br>
	 * Siehe dazu auch <code>positionID</code>
	 */
	private int position;
	
}