package ch.jaermann.quiz;

import java.io.File;
import java.util.List;

import org.junit.jupiter.api.Assertions;
import org.junit.jupiter.api.Test;

public class HelperTest {

	@Test
	public void testReplaceFirst() {
		String txt = "Hello, World!";
		String toReplace = "Hello";
		String replacement = "Hi";
		String expected = "Hi, World!";
		String actual = Helper.replaceFirst(txt, toReplace, replacement);
		Assertions.assertEquals(expected, actual);
	}

	@Test
	public void testReplaceAll() {
		StringBuilder txt = new StringBuilder("Hello, World!");
		String toReplace = "o";
		String replacement = "a";
		String expected = "Hella, Warld!";
		StringBuilder actual = Helper.replaceAll(txt, toReplace, replacement);
		Assertions.assertEquals(expected, actual.toString());
	}

	@Test
	public void testFindOption() {
		String option1 = "[1]";
		List<Integer> expected1 = List.of(1);
		List<Integer> actual1 = Helper.findOption(option1);
		Assertions.assertEquals(expected1, actual1);

		String option2 = "[1-3]";
		List<Integer> expected2 = List.of(1, 2, 3);
		List<Integer> actual2 = Helper.findOption(option2);
		Assertions.assertEquals(expected2, actual2);

		String option3 = "[1-3, 5,7]";
		List<Integer> expected3 = List.of(1, 2, 3, 5, 7);
		List<Integer> actual3 = Helper.findOption(option3);
		Assertions.assertEquals(expected3, actual3);

		String option4 = "[1-3, 5,7 , 12-15]";
		List<Integer> expected4 = List.of(1, 2, 3, 5, 7, 12, 13, 14, 15);
		List<Integer> actual4 = Helper.findOption(option4);
		Assertions.assertEquals(expected4, actual4);

		String option5 = "[1-3, 5,7 , 12-15 : r3]";
		List<Integer> actual5 = Helper.findOption(option5);
		Assertions.assertEquals(3, actual5.size());

		String option6 = "[1-3, 5,7 , 12-15 : r5]";
		List<Integer> actual6 = Helper.findOption(option6);
		Assertions.assertEquals(5, actual6.size());

		String option7 = "[1-3, 5,7 , 12-15 : r0]";
		List<Integer> actual7 = Helper.findOption(option7);
		Assertions.assertEquals(0, actual7.size());

		// maximale Anzahl
		String option8 = "[1-3 : r3]";
		List<Integer> actual8 = Helper.findOption(option8);
		Assertions.assertEquals(3, actual8.size());

		// maximale Anzahl überschritten
		String option9 = "[1-3 : r4]";
		List<Integer> actual9 = Helper.findOption(option9);
		Assertions.assertEquals(3, actual9.size());

		// keine Anzahl bei r, meint zufällige Reihenfolge
		String option10 = "[1-3 : r]";
		List<Integer> actual10 = Helper.findOption(option10);
		Assertions.assertEquals(3, actual10.size());

	}

	@Test
	public void testParseToIntWithValidString() {
		String stringToParse = "123";
		int defaultValue = 0;
		int expected = 123;
		int actual = Helper.parseToInt(stringToParse, defaultValue);
		Assertions.assertEquals(expected, actual);
	}

	@Test
	public void testParseToIntWithInvalidString() {
		String stringToParse = "abc";
		int defaultValue = 0;
		int expected = 0;
		int actual = Helper.parseToInt(stringToParse, defaultValue);
		Assertions.assertEquals(expected, actual);
	}

	@Test
	public void testParseToIntWithDefaultValue() {
		String stringToParse = "abc";
		int defaultValue = 456;
		int expected = 456;
		int actual = Helper.parseToInt(stringToParse, defaultValue);
		Assertions.assertEquals(expected, actual);
	}

	@Test
	public void testCreateZip() {
		String sourceFile = "readme.adoc";
		String zipFileName = "readme.zip";

		// Call the createZip method
		Helper.createZip(sourceFile, zipFileName);

		// Verify that the zip file is created
		File zipFile = new File(zipFileName);
		Assertions.assertTrue(zipFile.exists());
		
		// Clean up
		zipFile.delete();
	}

	@Test
	public void testCreateZipWithNonExistingSourceFile() {
		String sourceFile = "path/to/non/existing/file.txt";
		String zipFileName = "file.zip";

		// Call the createZip method
		Helper.createZip(sourceFile, zipFileName);

		// Verify that the zip file is not created
		File zipFile = new File(zipFileName);
		Assertions.assertFalse(zipFile.exists());
	}
}