package ch.jaermann.quiz;

import static org.junit.jupiter.api.Assertions.assertEquals;
import static org.junit.jupiter.api.Assertions.assertThrows;
import static org.junit.jupiter.api.Assertions.assertTrue;

import java.util.ArrayList;
import java.util.List;

import org.junit.jupiter.api.BeforeEach;
import org.junit.jupiter.api.Test;

import ch.jaermann.quiz.controller.QuizController;
import ch.jaermann.quiz.model.Answer;
import ch.jaermann.quiz.model.MultipleChoiceQuestion;
import ch.jaermann.quiz.model.Question;
import ch.jaermann.quiz.model.Quiz;
import ch.jaermann.quiz.model.SingleChoiceQuestion;

public class QuizControllerTest {

	private QuizController quizController;
	private Quiz quiz;

	@BeforeEach
	public void setUp() {
		quiz = new Quiz();
		quiz.setQuestions(new ArrayList<>());
		quizController = new QuizController(quiz);
	}

	@Test
	public void testGetAllIDs() {
		Question question1 = new MultipleChoiceQuestion();
		question1.setId(1);
		Question question2 = new SingleChoiceQuestion();
		question2.setId(2);
		quiz.getQuestions().add(question1);
		quiz.getQuestions().add(question2);

		List<Integer> expected = List.of(1, 2);
		List<Integer> actual = quizController.getAllIDs();

		assertEquals(expected, actual);
	}

	@Test
	public void testGetQuestionsID() {
		Question question1 = new MultipleChoiceQuestion();
		question1.setId(1);
		Question question2 = new SingleChoiceQuestion();
		question2.setId(2);
		quiz.getQuestions().add(question1);
		quiz.getQuestions().add(question2);

		Question expected = question1;
		Question actual = quizController.getQuestionsID(1);

		assertEquals(expected, actual);
	}

	@Test
	public void testGetQuestionsIDNotFound() {
		Question question1 = new MultipleChoiceQuestion();
		question1.setId(1);
		Question question2 = new SingleChoiceQuestion();
		question2.setId(2);
		quiz.getQuestions().add(question1);
		quiz.getQuestions().add(question2);

		int id = 3;

		IllegalArgumentException exception = assertThrows(IllegalArgumentException.class,
				() -> quizController.getQuestionsID(id));

		String expectedMessage = "Question with id " + id + " not found";
		String actualMessage = exception.getMessage();

		assertTrue(actualMessage.contains(expectedMessage));
	}

	@Test
	public void testCalculateTotalPoints() {
		Question question1 = new MultipleChoiceQuestion();
		Answer answer1 = new Answer();
		answer1.setAnswerPoints(2);
		Answer answer2 = new Answer();
		answer2.setAnswerPoints(3);
		question1.setAnswers(List.of(answer1, answer2));

		Question question2 = new SingleChoiceQuestion();
		Answer answer3 = new Answer();
		answer3.setAnswerPoints(4);
		Answer answer4 = new Answer();
		answer4.setAnswerPoints(1);
		question2.setAnswers(List.of(answer3, answer4));

		quiz.getQuestions().add(question1);
		quiz.getQuestions().add(question2);

		int expected = 10;
		int actual = quizController.calculateTotalPoints();

		assertEquals(expected, actual);
	}

	@Test
	public void testGetQuestionsWithId() {
		Question question1 = new MultipleChoiceQuestion();
		question1.setId(1);
		Question question2 = new SingleChoiceQuestion();
		question2.setId(2);
		quiz.getQuestions().add(question1);
		quiz.getQuestions().add(question2);

		List<Integer> list = List.of(1, 2);

		Quiz expected = new Quiz();
		expected.setQuestions(List.of(question1, question2));
		Quiz actual = quizController.getQuestionsWithId(list);

		assertEquals(expected, actual);
	}
}