package ch.jaermann.quiz;


import static org.junit.jupiter.api.Assertions.assertFalse;
import static org.junit.jupiter.api.Assertions.assertNotNull;
import static org.junit.jupiter.api.Assertions.assertTrue;

import java.io.File;
import java.io.IOException;
import java.net.URL;

import org.junit.jupiter.api.Test;

import com.fasterxml.jackson.core.exc.StreamReadException;
import com.fasterxml.jackson.databind.DatabindException;
import com.fasterxml.jackson.databind.ObjectMapper;

import ch.jaermann.quiz.smartlearn.model.Root;

/**
 * Lesen von SM-Exportdateien:<br>
 * Die Dateien, die SM aus einem Kurs erstellt und
 * zum Download bereitstellt, sollen vollständig geparst werden können. Damit
 * wird sichergestellt, dass das Erstellen eines korrekten JSON-Formats
 * ebenfalls zuverlässig funktioniert. Aus diesem Grund wurden umfangreiche
 * SM-Exporte hinzugefügt.
 */
public class ReadSmartlearnExportTest {
	
	public static void main(String[] args) throws IOException {
    	new ReadSmartlearnExportTest();
	}
	
	public ReadSmartlearnExportTest() throws IOException {
         testReadSimpleSmartlearnExportFile();
	}

	/**
	 * Umfangreiche Tests, um die Smartlearn Export Files zu lesen.<br>
	 * Es handelt sich um echte JSON-Files, die von Smartlearn exportiert wurden.
	 * @throws StreamReadException
	 * @throws DatabindException
	 * @throws IOException
	 */
    @Test
    public void testReadSimpleSmartlearnExportFile() throws StreamReadException, DatabindException, IOException {
    	
    	// File mit 
    	readAndWriteSmartlearnExportFile("smartlearn/SmartlearnAlleQuestions.json", "smartlearnExport55.json");
    	readAndWriteSmartlearnExportFile("smartlearn/smartlearnExport.json", "smartlearnExport55.json");
    	readAndWriteSmartlearnExportFile("smartlearn/SmartlearnExportVieleVerschiedene.json", "smartlearnExport55.json");
    	readAndWriteSmartlearnExportFile("smartlearn/m321.json", "smartlearnExport55.json");
    	readAndWriteSmartlearnExportFile("smartlearn/m254.json", "smartlearnExport55.json");
    	readAndWriteSmartlearnExportFile("smartlearn/m323_lb1.json", "smartlearnExport55.json");
    	readAndWriteSmartlearnExportFile("smartlearn/yesNoDontknow.json", "smartlearnExport55.json");
    }
    
	private void readAndWriteSmartlearnExportFile(String inputFileName, String outputFileName) throws IOException {
		// Arrange
		ObjectMapper mapper = new ObjectMapper();
        URL resource = getClass().getClassLoader().getResource(inputFileName);

		// Act
		Root root = (Root) mapper.readValue(new File(resource.getFile()), Root.class);

		// Jetzt kann root verwendet werden, um auf die Daten zuzugreifen
		writeToFile(outputFileName, root);
		
        // Assert
        assertNotNull(root);
        
        // Check if file exists
        File file = new File(outputFileName);
        assertTrue(file.exists());
        file.delete();
        assertFalse(file.exists());
	}
    
	private static void writeToFile(String fileName, Root root) {
		// Save to file
		ObjectMapper objectMapper = new ObjectMapper();
		try {
			objectMapper.writerWithDefaultPrettyPrinter().writeValue(new File(fileName), root);
		} catch (IOException e) {
			e.printStackTrace();
		}
	}
	
}